#!/bin/bash

# MYP Backend Autostart-Skript
# Installiert den MYP Backend-Dienst für automatischen Start beim Hochfahren

# Skript muss als root ausgeführt werden
if [ "$EUID" -ne 0 ]; then
  echo "Dieses Skript muss als root ausgeführt werden."
  echo "Bitte mit 'sudo' ausführen."
  exit 1
fi

# Aktuelles Verzeichnis bestimmen
SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
echo "Installiere MYP Backend Service aus: $SCRIPT_DIR"

# Überprüfen, ob die Service-Datei existiert
if [ ! -f "$SCRIPT_DIR/myp-backend.service" ]; then
  echo "Fehler: myp-backend.service nicht gefunden!"
  exit 1
fi

# Service-Datei in systemd-Verzeichnis kopieren
cp "$SCRIPT_DIR/myp-backend.service" /etc/systemd/system/
echo "Service-Datei nach /etc/systemd/system/ kopiert."

# Systemd neu laden und Service aktivieren
systemctl daemon-reload
systemctl enable myp-backend.service
echo "MYP Backend Service wurde für Autostart beim Systemstart aktiviert."

# Aktuellen Status anzeigen
echo "Starte den MYP Backend Service..."
systemctl start myp-backend.service
systemctl status myp-backend.service

echo ""
echo "Installation abgeschlossen!"
echo "Verwende folgende Befehle zur Steuerung des Dienstes:"
echo "  sudo systemctl start myp-backend    # Service starten"
echo "  sudo systemctl stop myp-backend     # Service stoppen"
echo "  sudo systemctl restart myp-backend  # Service neu starten"
echo "  sudo systemctl status myp-backend   # Status anzeigen"
echo "  journalctl -u myp-backend -f        # Logs anzeigen"