describe('Printer reservation workflow', () => {
  beforeEach(() => {
    // Login without OAuth
    cy.login()
    
    // Mock API responses
    cy.intercept('GET', '/api/printers', [
      { 
        id: '1', 
        name: 'Drucker 1', 
        description: 'Test Drucker', 
        status: 'available',
        printJobs: []
      }
    ]).as('getPrinters')
  })

  it('allows a user to view and reserve a printer', () => {
    cy.visit('/')
    cy.wait('@getPrinters')
    
    // Check printer is shown and available
    cy.contains('Drucker 1')
    cy.contains('Verfügbar')
    
    // Start reservation process
    cy.contains('Reservieren').click()
    
    // Fill in the form
    cy.get('input[name="hours"]').clear().type('1')
    cy.get('input[name="minutes"]').clear().type('30')
    cy.get('textarea[name="comments"]').type('Testauftrag')
    
    // Mock job creation
    cy.intercept('POST', '/api/printers/*/reserve', {
      id: 'job-123',
      printerId: '1',
      userId: 'test-user-id',
      startTime: new Date().toISOString(),
      endTime: new Date(Date.now() + 90 * 60000).toISOString(),
      status: 'active'
    }).as('createJob')
    
    // Submit the form
    cy.contains('button', 'Reservieren').click()
    cy.wait('@createJob')
    
    // Verify successful reservation
    cy.url().should('include', '/job/')
    cy.contains('Druckauftrag').should('exist')
  })
})