#!/bin/bash

# MYP-System Startskript
# Dieses Skript startet das MYP-System mit Docker (falls installiert)

set -e  # Bei Fehler beenden

# Farbcodes für Ausgabe
RED='\033[0;31m'
GREEN='\033[0;32m'
YELLOW='\033[0;33m'
BLUE='\033[0;34m'
NC='\033[0m' # No Color

# Funktion zur Ausgabe mit Zeitstempel
log() {
  echo -e "${BLUE}[$(date +'%Y-%m-%d %H:%M:%S')]${NC} $1"
}

# Frontend starten
start_frontend() {
  log "${GREEN}Starte Frontend...${NC}"
  
  # In das Frontend-Verzeichnis wechseln
  cd "$(dirname "$0")/packages/reservation-platform"
  
  # Prüfen ob docker-compose.yml vorhanden ist
  if [ ! -f docker-compose.yml ]; then
    log "${RED}docker-compose.yml nicht gefunden. Bitte führen Sie zuerst install-myp.sh aus.${NC}"
    exit 1
  fi
  
  # Container starten oder neu starten
  docker-compose start || docker-compose up -d
  
  log "${GREEN}Frontend gestartet unter http://localhost:3000${NC}"
}

# Backend starten
start_backend() {
  log "${GREEN}Starte Backend...${NC}"
  
  # In das Backend-Verzeichnis wechseln
  cd "$(dirname "$0")/backend"
  
  # Prüfen ob docker-compose.yml vorhanden ist
  if [ ! -f docker-compose.yml ]; then
    log "${RED}docker-compose.yml nicht gefunden. Bitte führen Sie zuerst install-myp.sh aus.${NC}"
    exit 1
  fi
  
  # Container starten oder neu starten
  docker-compose start || docker-compose up -d
  
  log "${GREEN}Backend gestartet unter http://localhost:5000${NC}"
}

# Hauptprogramm
main() {
  log "${BLUE}=== MYP-System starten ===${NC}"
  
  # Frontend starten
  start_frontend
  
  # Backend starten
  start_backend
  
  log "${GREEN}=== MYP-System läuft ===${NC}"
  log "Frontend: http://localhost:3000"
  log "Backend: http://localhost:5000"
  log "Um das System zu stoppen: ./stop-myp.sh"
}

# Ausführen
main