#!/bin/bash

# MYP-System Stoppskript
# Dieses Skript stoppt das MYP-System mit Docker

set -e  # Bei Fehler beenden

# Farbcodes für Ausgabe
RED='\033[0;31m'
GREEN='\033[0;32m'
YELLOW='\033[0;33m'
BLUE='\033[0;34m'
NC='\033[0m' # No Color

# Funktion zur Ausgabe mit Zeitstempel
log() {
  echo -e "${BLUE}[$(date +'%Y-%m-%d %H:%M:%S')]${NC} $1"
}

# Frontend stoppen
stop_frontend() {
  log "${YELLOW}Stoppe Frontend...${NC}"
  
  # In das Frontend-Verzeichnis wechseln
  cd "$(dirname "$0")/packages/reservation-platform"
  
  # Prüfen ob docker-compose.yml vorhanden ist
  if [ ! -f docker-compose.yml ]; then
    log "${YELLOW}docker-compose.yml nicht gefunden. Frontend scheint nicht installiert zu sein.${NC}"
    return
  fi
  
  # Container stoppen
  docker-compose stop
  
  log "${GREEN}Frontend gestoppt${NC}"
}

# Backend stoppen
stop_backend() {
  log "${YELLOW}Stoppe Backend...${NC}"
  
  # In das Backend-Verzeichnis wechseln
  cd "$(dirname "$0")/backend"
  
  # Prüfen ob docker-compose.yml vorhanden ist
  if [ ! -f docker-compose.yml ]; then
    log "${YELLOW}docker-compose.yml nicht gefunden. Backend scheint nicht installiert zu sein.${NC}"
    return
  fi
  
  # Container stoppen
  docker-compose stop
  
  log "${GREEN}Backend gestoppt${NC}"
}

# Hauptprogramm
main() {
  log "${BLUE}=== MYP-System stoppen ===${NC}"
  
  # Frontend stoppen
  stop_frontend
  
  # Backend stoppen
  stop_backend
  
  log "${GREEN}=== MYP-System gestoppt ===${NC}"
}

# Ausführen
main